#
# spec file for package perl-Data-Dump
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Data-Dump
Name:           perl-Data-Dump
Version:        1.25
Release:        1.11
Summary:        Pretty printing of data structures
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/G/GA/GARU/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module provides a few functions that traverse their argument list and
return a string containing Perl code that, when 'eval'ed, produces a deep
copy of the original arguments.

The main feature of the module is that it strives to produce output that is
easy to read. Example:

    @a = (1, [2, 3], {4 => 5});
    dump(@a);

Produces:

    "(1, [2, 3], { 4 => 5 })"

If you dump just a little data, it is output on a single line. If you dump
data that is more complex or there is a lot of it, line breaks are
automatically added to keep it easy to read.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Tue Jun 29 2021 Tina Müller <tina.mueller@suse.com>
- Limit description paragraphs
* Sun Jun 27 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.25
  see /usr/share/doc/packages/perl-Data-Dump/Changes
  2021-06-26  Breno G. de Oliveira <garu@cpan.org>
    Release 1.25
    New option $Data::Dump::LINEWIDTH controls when to perform a
    linebreak (default is 60). Many thanks to Jonas Kramer, Rob Kinyon,
    cybernicus and Lady Aleena for submitting reports and pull requests.
  2021-06-25  Breno G. de Oliveira <garu@cpan.org>
    Release 1.24
    Strings like "NaN" are still strings
    Update maintainer and repository information
* Sun Jun 14 2015 coolo@suse.com
- updated to 1.23
  see /usr/share/doc/packages/perl-Data-Dump/Changes
  2015-06-09  Gisle Aas <gisle@ActiveState.com>
    Release 1.23
    Avoid "Negative repeat count does nothing"-warnings from perl-5.22
    Typo fixes by David Steinbrunner
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.22
  Deal with class names containing '=' [RT#72415]
  Filters now get access to $ctx->expr; the textual expression
  denoting the current object.
* Wed Mar  7 2012 andrea.turrini@gmail.com
- fixed typos in perl-Data-Dump.spec description
* Thu Dec 22 2011 coolo@suse.com
- update to 1.21
  Make dump($1) work when $1 was integer [RT#63883]
  Dump floats without quoting
  Add depth() method to FilterContext
  Make dump($1) work [RT#63883]
  Limit our temp listen socket to localhost [RT#63534]
* Thu Mar  3 2011 pascal.bleser@opensuse.org
- update to 1.19
- changes from 1.18:
  * don't downgrade is_utf8-strings with MIME::Base64 [RT#60103]
  * deal with the perl-5.13 (?^:...) regex construct [RT#61552]
- changes from 1.17:
  * fix dump of "1\n" (the newline was lost) [RT#56595]
  * start using the range operator to shorten list dumps; for instance
    dump(1,2,3,4,5) now returns '(1 .. 5)'
  * CODE references now dumped as 'sub { ... }'
  * fix how multiline hash values are indented
  * make indentation configurable
- changes from 1.16:
  * add support for filter callbacks
    + filters can modify how selected objects are dumped
  * various enhancements to how/when hash keys are quoted
    + don't quote keywords
    + don't quote words prefixed with "-"
    + don't quote long identifier keys
    + quote all hash keys if one needs quoting for better alignment
  * use case-insensitive sorting for hash keys
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Apr  3 2010 chris@computersalat.de
- update to 1.15
  Fixed regexp that determines if hash keys are numeric [RT#48003]
- Release 1.14
  - Data::Dump::Trace enhancements:
  - trace() function
  - prototypes
- Release 1.13
  - Added the Data::Dump::Trace module
- Release 1.12
  - Documentation tweaks.
- Release 1.11
  - Documentation tweaks.
- Release 1.10
  - Add the functions quote(), dd() and ddx().
  - Fix segfault when duming large repeated strings [RT#33520]
  - Incorporated documentation improvements from Mark Stosberg
  - Apply Data-Dump-1.08-ANDK-01.patch from CPAN.  Might do some
    good on older perls I guess.
- Release 1.08
  - By popular demand; don't put underscore into dumped integers
    to group thousands.
- Release 1.07
  - Remove unused code.
  - Add some more tests.
- spec mods
  o HEADER, TAGS, deps, macros
- added perl-macros
* Thu Jun 22 2006 jfunk@funktronics.ca
- Build under buildservice
* Fri Oct 28 2005 jfunk@funktronics.ca
- Build for SL10
* Mon Jun  6 2005 jfunk@funktronics.ca
- Build for SL93
* Sat Dec 18 2004 jfunk@funktronics.ca
- Update
- Build for SL92
* Mon May 17 2004 jfunk@funktronics.ca
- Build for SL91
* Fri Nov  7 2003 jfunk@funktronics.ca
- Initial release
